
EURAC
=====
You can find the relevant code for the EURAC use case in the 
`use case's folder on Github <https://github.com/interTwin-eu/itwinai/tree/main/use-cases/eurac>`_,
or by consulting the use case's README: 


.. include:: ../../use-cases/eurac/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2
